@@ -1,4 +1,4 @@
-__version__=0.2
+__version__=0.3
 
 ### Load the FairDetect Class
 import time
@@ -24,7 +24,7 @@ class Fairdetect:
     def __init__(self,model,X_test,y_test):
         self.model,self.X_test,self.y_test = model, X_test, y_test
     
-    def check_for_target(self):
+    def check_for_target(self,data_bd):
         """
         Allows user to define the target variable out of the columns available
         Checks if target variable is Binary or not. Only binary target variable accepted
@@ -33,14 +33,14 @@ class Fairdetect:
         ------
         Selection of the target variable from all columns of the dataframe
         """
-        print(data.columns.values)
-        self.target_column = input("Please select target column")
-        if not(set(data[self.target_column].unique())==set([0,1])):
+        print(data_bd.columns.values)
+        data_bd.target_column = input("Please select target column")
+        if not(set(data[data_bd.target_column].unique())==set([0,1])):
             raise ValueError('Only binary target variable')
         else:
-            print("You choose wisely. Your target variable is:", self.target_column)
+            print("You choose wisely. Your target variable is:", data_bd.target_column)
         
-        return self.target_column
+        return data_bd.target_column
     
     
     def create_labels(self,sensitive):
